@@ -5,8 +5,12 @@ from .get_bearer_token import get_bearer_token
 
 def push_software(config, fpath, radarType, version_name):
     print('Getting the bearer token...')
-    api_url = config['api_url']
+    # check config file
+    print('config api_url: ', config['api_url'])
+    request_url = config['api_url']
+
     bearer_token = get_bearer_token(config)
+
     headers = {
         'Authorization': 'Bearer ' + bearer_token,
     }
@@ -32,5 +36,5 @@ def push_software(config, fpath, radarType, version_name):
     
     print('Uploading software...')
 
-    response = requests.post(api_url+'/api/softwares/softwarefiles', headers=headers, data=values, files=files)
+    response = requests.post(request_url + '/api/softwares/softwarefiles', headers=headers, data=values, files=files)
     return response.json()
\ No newline at end of file
